==> multiscan_1.12.0.zip: multiscan/doc/multiscan.R <==
###################################################
### chunk number 1: 
###################################################
#line 71 "multiscan.Rnw"
library(multiscan)


###################################################
### chunk number 2:  eval=FALSE
###################################################
## #line 86 "multiscan.Rnw"
## vignette("multiscan")


###################################################
### chunk number 3: 
###################################################
#line 108 "multiscan.Rnw"
data(murine)


###################################################
### chunk number 4: 
###################################################
#line 114 "multiscan.Rnw"
murine[1:10,]


###################################################
### chunk number 5:  eval=FALSE
###################################################
## #line 120 "multiscan.Rnw"
## help(murine)


###################################################
### chunk number 6: 
###################################################
#line 129 "multiscan.Rnw"
data(murine)
fit<-multiscan(murine)
fit


###################################################
### chunk number 7: 
###################################################
#line 136 "multiscan.Rnw"
str(fit)


###################################################
### chunk number 8: 
###################################################
#line 143 "multiscan.Rnw"
gene.exprs<-fit$mu


###################################################
### chunk number 9:  eval=FALSE
###################################################
## #line 150 "multiscan.Rnw"
## plot(fit)


###################################################
### chunk number 10: fitted
###################################################
#line 157 "multiscan.Rnw"
plot(fit)


###################################################
### chunk number 11:  eval=FALSE
###################################################
## #line 169 "multiscan.Rnw"
## help(multiscan)


###################################################
### chunk number 12:  eval=FALSE
###################################################
## #line 179 "multiscan.Rnw"
## op<-par(mfrow=c(2,2))
## plot(fit,residual=TRUE)
## par(op)


###################################################
### chunk number 13: sdres
###################################################
#line 188 "multiscan.Rnw"
op<-par(mfrow=c(2,2))
plot(fit,residual=TRUE)
par(op)

==> multiscan_1.46.0.zip: multiscan/doc/multiscan.R <==
### R code from vignette source 'multiscan.Rnw'

###################################################
### code chunk number 1: multiscan.Rnw:70-71
###################################################
library(multiscan)


###################################################
### code chunk number 2: multiscan.Rnw:85-86 (eval = FALSE)
###################################################
## vignette("multiscan")


###################################################
### code chunk number 3: multiscan.Rnw:107-108
###################################################
data(murine)


###################################################
### code chunk number 4: multiscan.Rnw:113-114
###################################################
murine[1:10,]


###################################################
### code chunk number 5: multiscan.Rnw:119-120 (eval = FALSE)
###################################################
## help(murine)


###################################################
### code chunk number 6: multiscan.Rnw:128-131
###################################################
data(murine)
fit<-multiscan(murine)
fit


###################################################
### code chunk number 7: multiscan.Rnw:135-136
###################################################
str(fit)


###################################################
### code chunk number 8: multiscan.Rnw:142-143
###################################################
gene.exprs<-fit$mu


###################################################
### code chunk number 9: multiscan.Rnw:149-150 (eval = FALSE)
###################################################
## plot(fit)


###################################################
### code chunk number 10: fitted
###################################################
plot(fit)


###################################################
### code chunk number 11: multiscan.Rnw:168-169 (eval = FALSE)
###################################################
## help(multiscan)


###################################################
### code chunk number 12: multiscan.Rnw:178-181 (eval = FALSE)
###################################################
## op<-par(mfrow=c(2,2))
## plot(fit,residual=TRUE)
## par(op)


###################################################
### code chunk number 13: sdres
###################################################
op<-par(mfrow=c(2,2))
plot(fit,residual=TRUE)
par(op)
